Coverage for ezdag/__init__.py: 77.8%

1# Copyright (C) 2022 Patrick Godwin

2#

3# This Source Code Form is subject to the terms of the Mozilla Public License, v2.0.

4# If a copy of the MPL was not distributed with this file, You can obtain one at

5# <https://mozilla.org/MPL/2.0/>.

6#

7# SPDX-License-Identifier: MPL-2.0

8

9 from .dags import DAG as DAG

10 from .layers import Layer as Layer

11 from .layers import Node as Node

12 from .options import Argument as Argument

13 from .options import Option as Option

14

15 try:

16 from ._version import version as __version__

17 except ModuleNotFoundError: # development mode

18 __version__ = ""